=====
ArtD Partner
=====
Art Partner is a package that makes it possible to manage headquarters, locations, co-workers, etc.
Quick start
-----------
1. Add to your INSTALLED_APPS setting like this::
INSTALLED_APPS = [
        ...
        'artd_location',
        'artd_partner',
    ]
2. Run `python manage.py migrate` to create the models.